@@ -13,7 +13,7 @@ from contextvars import ContextVar
 from functools import partial, update_wrapper, cached_property
 from itertools import chain
 from typing import TYPE_CHECKING, Any, Type, Generic, Optional, Callable, Collection, Union, Iterator, overload
-from typing import List, Tuple, FrozenSet
+from typing import Iterable, List, Tuple, FrozenSet
 
 from ..annotations import get_descriptor_value_type
 from ..config import CommandConfig, OptionNameMode, AllowLeadingDash, DEFAULT_CONFIG
@@ -21,16 +21,17 @@ from ..context import Context, ctx, get_current_context
 from ..exceptions import ParameterDefinitionError, BadArgument, MissingArgument, InvalidChoice
 from ..exceptions import ParamUsageError, UnsupportedAction
 from ..inputs import InputType, normalize_input_type
-from ..inputs.choices import _ChoicesBase, Choices, ChoiceMap as ChoiceMapInput
+from ..inputs.choices import _ChoicesBase
 from ..inputs.exceptions import InputValidationError, InvalidChoiceError
 from ..nargs import Nargs, REMAINDER
-from ..typing import Bool, ValSrc, OptStrs, CommandCls, CommandObj, CommandAny, Param, LeadingDash, T_co
+from ..typing import T_co
 from ..utils import _NotSet, ValueSource
 from .option_strings import OptionStrings
 
 if TYPE_CHECKING:
     from types import MethodType
     from ..formatting.params import ParamHelpFormatter
+    from ..typing import OptStr, OptStrs, Bool, ValSrc, CommandCls, CommandObj, CommandAny, Param, LeadingDash
     from .groups import ParamGroup
 
 __all__ = ['Parameter', 'BasePositional', 'BaseOption']
@@ -106,8 +107,8 @@ class ParamBase(ABC):
         self.name = name
         self.help = help
         self.hide = hide
-        if group := get_active_param_group():
-            group.register(self)  # noqa  # This sets self.group = group
+        if param_groups := _group_stack.get(None):  # If truthy, there's at least 1 active ParamGroup
+            param_groups[-1].register(self)  # This sets self.group = group
 
     @property
     def name(self) -> str:
@@ -204,9 +205,9 @@ class Parameter(ParamBase, Generic[T_co], ABC):
     # Class attributes
     _actions: FrozenSet[str] = frozenset()          #: The actions supported by this Parameter
     _repr_attrs: Optional[Collection[str]] = None   #: Attributes to include in ``repr()`` output
-    accepts_none: bool = False                      #: Whether this Parameter can be provided without a value
     accepts_values: bool = True                     #: Whether this Parameter can be provided with at least 1 value
     # Instance attributes with class defaults
+    accepts_none: bool = False                      #: Whether this Parameter can be provided without a value
     metavar: str = None
     nargs: Nargs = Nargs(1)                         # Set in subclasses
     type: Optional[Callable[[str], T_co]] = None    # Only set here if not set by __init__ in Option/Positional
@@ -324,12 +325,21 @@ class Parameter(ParamBase, Generic[T_co], ABC):
         return parsed, nargs_max_reached
 
     def take_action(
-        self, value: Optional[str], short_combo: bool = False, opt_str: str = None, src: ValSrc = ValueSource.CLI
-    ):
+        self, value: OptStr, short_combo: Bool = False, opt_str: OptStr = None, src: ValSrc = ValueSource.CLI
+    ) -> int:
+        """
+        :param value: The parsed value or None
+        :param short_combo: Only True when a short option was provided, where the option string was combined with
+          either a real value or a sequence of 1-char combinable versions of short option strings.
+        :param opt_str: The option string that preceded the given value, or a single char that was combined with
+          other 1-char combinable versions of short option strings.
+        :param src: The source for the value - either CLI or env var
+        :return: The number of new values discovered
+        """
         ctx.record_action(self)
         return getattr(self, self.action)(self.prepare_and_validate(value, short_combo))
 
-    def would_accept(self, value: str, short_combo: bool = False) -> bool:
+    def would_accept(self, value: str, short_combo: Bool = False) -> bool:
         action = self.action
         if action in {'store', 'store_all'} and ctx.get_parsed_value(self) is not _NotSet:
             return False
@@ -341,7 +351,7 @@ class Parameter(ParamBase, Generic[T_co], ABC):
             return False
         return self.is_valid_arg(normalized)
 
-    def prepare_and_validate(self, value: str, short_combo: bool = False) -> T_co:
+    def prepare_and_validate(self, value: OptStr, short_combo: Bool = False) -> T_co:
         """Called by :meth:`.take_action` to prepare/validate the value before it is passed to the action method."""
         if value is not None:
             value = self.prepare_value(value, short_combo)
@@ -349,7 +359,7 @@ class Parameter(ParamBase, Generic[T_co], ABC):
         return value
 
     def prepare_value(  # pylint: disable=W0613
-        self, value: str, short_combo: bool = False, pre_action: bool = False
+        self, value: str, short_combo: Bool = False, pre_action: Bool = False
     ) -> T_co:
         type_func = self.type
         if type_func is None or (pre_action and isinstance(type_func, InputType) and type_func.is_valid_type(value)):
@@ -651,10 +661,3 @@ class BaseOption(Parameter[T_co], ABC):
                 yield env_var
             else:
                 yield from env_var
-
-
-def get_active_param_group() -> Optional[ParamGroup]:
-    try:
-        return _group_stack.get()[-1]
-    except (LookupError, IndexError):
-        return None
