@@ -9,12 +9,13 @@ from __future__ import annotations
 # import logging
 from collections import deque
 from os import environ
-from typing import TYPE_CHECKING, Optional, Union, Any, Deque, List
+from typing import TYPE_CHECKING, Optional, Union, Any, Iterable, Deque, List
 
+from .core import get_parent
 from .context import ActionPhase, Context
 from .exceptions import UsageError, ParamUsageError, NoSuchOption, MissingArgument, ParamsMissing
 from .exceptions import Backtrack, NextCommand, UnsupportedAction
-from .nargs import REMAINDER, nargs_max_sum, nargs_min_sum
+from .nargs import REMAINDER, nargs_min_and_max_sums
 from .parse_tree import PosNode
 from .parameters.base import BasicActionMixin, Parameter, BasePositional, BaseOption
 from .utils import ValueSource
@@ -22,11 +23,13 @@ from .utils import ValueSource
 if TYPE_CHECKING:
     from .command_parameters import CommandParameters
     from .config import CommandConfig
-    from .typing import CommandType
+    from .typing import CommandType, OptStr
 
 __all__ = ['CommandParser']
 # log = logging.getLogger(__name__)
 
+_PRE_INIT = ActionPhase.PRE_INIT
+
 
 class CommandParser:
     """Stateful parser used for a single pass of argument parsing"""
@@ -62,25 +65,25 @@ class CommandParser:
         params = self.params
         params.validate_groups()
         missing = ctx.get_missing()
-        no_pre_init_action = not ctx.categorized_action_flags[ActionPhase.PRE_INIT]
-        next_cmd = params.sub_command.target() if params.sub_command else None
-        if next_cmd is not None:
-            if missing and no_pre_init_action and next_cmd.__class__.parent(next_cmd) is not ctx.command:
+        if (sub_cmd_param := params.sub_command) and (next_cmd := sub_cmd_param.target()) is not None:
+            if missing and not ctx.categorized_action_flags[_PRE_INIT] and get_parent(next_cmd) is not ctx.command:
                 raise ParamsMissing(missing)
+            return next_cmd
         elif missing and not ctx.config.allow_missing and (not params.action or params.action not in missing):
-            if no_pre_init_action:
+            if not ctx.categorized_action_flags[_PRE_INIT]:  # No pre-init action was triggered
                 raise ParamsMissing(missing)
-        elif ctx.remaining and not ctx.config.ignore_unknown:
+        elif ctx.remaining and not ctx.config.ignore_unknown:  # Note: ctx.remaining is self.deferred at this point
             raise NoSuchOption(f'unrecognized arguments: {" ".join(ctx.remaining)}') from None
-        return next_cmd
+        return None
 
     def _parse_args(self, ctx: Context):
         self.arg_deque = arg_deque = self.handle_pass_thru(ctx)
         self.deferred = ctx.remaining = []
+
         while arg_deque:
             arg = arg_deque.popleft()
             try:
-                if self._parse_arg(ctx, arg):
+                if self._handle_arg(arg):
                     break
             except NextCommand:
                 self.deferred.append(arg)
@@ -89,27 +92,6 @@ class CommandParser:
 
         self._parse_env_vars(ctx)
 
-    def _parse_arg(self, ctx: Context, arg: str):
-        if arg == '--':
-            if self._maybe_consume_remainder(arg):
-                return True
-            elif ctx.params.find_nested_pass_thru():  # pylint: disable=R1723
-                # TODO: Make sure a test exists where parsing fails because required params were not provided yet
-                raise NextCommand
-            else:
-                raise NoSuchOption(f'invalid argument: {arg}')
-        elif arg.startswith('---'):
-            if not self._maybe_consume_remainder(arg):
-                raise NoSuchOption(f'invalid argument: {arg}')
-        elif arg.startswith('--'):
-            self.handle_long(arg)
-        elif arg.startswith('-') and arg != '-':
-            self.handle_short(arg)
-        else:
-            self.handle_positional(arg)
-
-        return False
-
     def _parse_env_vars(self, ctx: Context):
         # TODO: It would be helpful to store arg provenance for error messages, especially for a conflict between
         #  mutually exclusive params when they were provided via env
@@ -124,10 +106,35 @@ class CommandParser:
                     param.take_action(value, src=(env, env_var))
                     break
 
+    def _handle_arg(self, arg: str):
+        if not arg or arg[0] != '-':
+            return self.handle_positional(arg)
+        n = len(arg)
+        if n > 1 and arg[1] != '-':  # arg starts with 1 dash followed by a non-dash
+            return self.handle_short(arg)
+        elif n > 2:  # arg starts with at least 1 dash, and may be a long option or invalid
+            return self.handle_long(arg) if arg[2] != '-' else self._handle_many_dashes(arg)
+        else:  # arg == '--'
+            return self._handle_double_dash(arg)
+
+    def _handle_double_dash(self, arg: str):
+        if self._maybe_consume_remainder(arg):
+            return True
+        elif self.params.find_nested_pass_thru():  # pylint: disable=R1723
+            # TODO: Make sure a test exists where parsing fails because required params were not provided yet
+            raise NextCommand
+        else:
+            raise NoSuchOption(f'invalid argument: {arg}')
+
+    def _handle_many_dashes(self, arg: str):
+        if not self._maybe_consume_remainder(arg):
+            raise NoSuchOption(f'invalid argument: {arg}')
+
+    # region PassThru / Remainder Handling
+
     def handle_pass_thru(self, ctx: Context) -> Deque[str]:
         remaining = ctx.remaining
-        pass_thru = self.params.pass_thru
-        if pass_thru is not None:
+        if pass_thru := self.params.pass_thru:
             try:
                 separator_pos = remaining.index('--')
             except ValueError:
@@ -153,27 +160,28 @@ class CommandParser:
             found += param.take_action(arg_deque.popleft())
         return found
 
+    # endregion
+
     def handle_positional(self, arg: str):
         # log.debug(f'handle_positional({arg=})')
-        try:
-            param: BasePositional = self.positionals.pop(0)
-        except IndexError:
-            self.deferred.append(arg)
-        else:
+        if positionals := self.positionals:
+            param: BasePositional = positionals.pop(0)
             if param.nargs.max is REMAINDER:
                 self.handle_remainder(param, arg)
             else:
                 try:
                     found = param.take_action(arg)
                 except UsageError:
-                    self.positionals.insert(0, param)
+                    positionals.insert(0, param)
                     raise
                 try:
                     self.consume_values(param, found=found)
                 except Backtrack:
-                    self.positionals.insert(0, param)
+                    positionals.insert(0, param)
                 else:
                     self._last = param
+        else:
+            self.deferred.append(arg)
 
     def handle_long(self, arg: str):
         # log.debug(f'handle_long({arg=})')
@@ -190,6 +198,8 @@ class CommandParser:
                 param.take_action(None, opt_str=opt)
             self._last = param
 
+    # region Short Option Handling
+
     def handle_short(self, arg: str):
         # log.debug(f'handle_short({arg=})')
         try:
@@ -201,8 +211,8 @@ class CommandParser:
             last = param_val_combos.pop()
             if param_val_combos:
                 # Note: This loop is only executed for single char combined flags, where the values will always be None
-                for opt, param, value in param_val_combos:
-                    param.take_action(value, short_combo=True, opt_str=opt)
+                for opt, param, none_value in param_val_combos:
+                    param.take_action(none_value, short_combo=True, opt_str=opt)
             self._handle_short_value(*last)
 
     def _handle_short_not_found(self, arg: str):
@@ -226,18 +236,18 @@ class CommandParser:
         self._last = param
         # No need to raise MissingArgument if values were not consumed - consume_values handles checking nargs
 
+    # endregion
+
     def _check_sub_command_options(self, arg: str):
         # log.debug(f'_check_sub_command_options({arg=})')
         # This check is only needed when subcommand option values may be misinterpreted as positional values
-        if not self.positionals:
-            return
-        param = self.params.find_nested_option_that_accepts_values(arg)
-        if param is None:
-            return
-        elif len(self.positionals) == 1 and 0 in self.positionals[0].nargs:
-            raise NextCommand
-        else:
-            raise ParamUsageError(param, 'subcommand arguments must be provided after the subcommand')
+        if (positionals := self.positionals) and (param := self.params.find_nested_option_that_accepts_values(arg)):
+            if len(positionals) == 1 and 0 in positionals[0].nargs:
+                raise NextCommand
+            else:
+                raise ParamUsageError(param, 'subcommand arguments must be provided after the subcommand')
+
+    # region Backtracking
 
     def _maybe_backtrack(self, param: Parameter, found: int) -> int:
         """
@@ -249,17 +259,12 @@ class CommandParser:
         :param found: The number of values that were consumed by the given Parameter
         :return: The updated found count, if backtracking was possible, otherwise the unmodified found count
         """
-        if not self.config.allow_backtrack or not self.positionals or found < 2:
+        if (positionals := self.positionals) and (to_pop := _to_pop(positionals, param.can_pop_counts(), found - 1)):
+            self.arg_deque.extendleft(reversed(param.pop_last(to_pop)))
+            return found - to_pop
+        else:
             return found
 
-        can_pop = param.can_pop_counts()
-        to_pop = _to_pop(self.positionals, can_pop, found - 1)
-        if to_pop is None:
-            return found
-
-        self.arg_deque.extendleft(reversed(param.pop_last(to_pop)))
-        return found - to_pop
-
     def _maybe_backtrack_last(self, param: Union[BasePositional, BasicActionMixin], found: int):
         """
         Similar to :meth:`._maybe_backtrack`, but allows backtracking even after starting to process a Positional.
@@ -268,18 +273,19 @@ class CommandParser:
             return
 
         can_pop = self._last.can_pop_counts()
-        to_pop = _to_pop([param, *self.positionals], can_pop, max(can_pop, default=0) + found, found)
-        if to_pop is None:
+        if to_pop := _to_pop((param, *self.positionals), can_pop, max(can_pop, default=0) + found, found):
+            try:
+                reset = param._reset()
+            except UnsupportedAction:
+                return
+
+            self.arg_deque.extendleft(reversed(reset))
+            self.arg_deque.extendleft(reversed(self._last.pop_last(to_pop)))
+            raise Backtrack
+        else:
             return
 
-        try:
-            reset = param._reset()
-        except UnsupportedAction:
-            return
-
-        self.arg_deque.extendleft(reversed(reset))
-        self.arg_deque.extendleft(reversed(self._last.pop_last(to_pop)))
-        raise Backtrack
+    # endregion
 
     def consume_values(self, param: Parameter, found: int = 0) -> int:
         """
@@ -289,45 +295,41 @@ class CommandParser:
         :param found: The number of already discovered values for that Parameter (only specified for positional params)
         :return: The total number of values that were found for the given Parameter.
         """
-        remainder = param.nargs.max is REMAINDER
-        while True:
-            try:
-                value = self.arg_deque.popleft()
-            except IndexError:
-                # log.debug(f'Ran out of values in deque while processing {param=}')
-                found = self._maybe_backtrack(param, found)
-                return self._finalize_consume(param, None, found)
-            else:
-                # log.debug(f'Found {value=} in deque - may use it for {param=}')
-                if remainder:
-                    return self.handle_remainder(param, value)
-                elif value.startswith('--'):
+        arg_deque = self.arg_deque
+        if param.nargs.max is REMAINDER and arg_deque:
+            return self.handle_remainder(param, arg_deque.popleft())
+
+        while arg_deque:
+            value = arg_deque.popleft()
+            # log.debug(f'Found {value=} in deque - may use it for {param=}')
+            if prefix := get_opt_prefix(value):
+                if prefix == '--' or self.params.has_matching_short_option(value):
                     return self._finalize_consume(param, value, found)
-                elif value.startswith('-') and value != '-':
-                    if self.params.get_option_param_value_pairs(value):
-                        # log.debug(f'{value=} will not be used with {param=} - it is also a parameter')
-                        return self._finalize_consume(param, value, found)
-                    else:
-                        try:
-                            self._check_sub_command_options(value)
-                        except (ParamUsageError, NextCommand) as e:
-                            return self._finalize_consume(param, value, found, e)
-
-                    if not param.would_accept(value):
-                        # log.debug(f'{value=} will not be used with {param=} - it would not be accepted')
-                        return self._finalize_consume(param, value, found, NoSuchOption(f'invalid argument: {value}'))
-                    # log.debug(f'{value=} may be used with {param=} as a value')
-
+                # Beyond this point, prefix == '-'
                 try:
-                    found += param.take_action(value)
-                except UsageError as e:
-                    # log.debug(f'{value=} was rejected by {param=}', exc_info=True)
+                    self._check_sub_command_options(value)
+                except (ParamUsageError, NextCommand) as e:
                     return self._finalize_consume(param, value, found, e)
 
-    def _finalize_consume(
-        self, param: Parameter, value: Optional[str], found: int, exc: Optional[Exception] = None
-    ) -> int:
-        if param.nargs.satisfied(found):
+                if not param.would_accept(value):
+                    # log.debug(f'{value=} will not be used with {param=} - it would not be accepted')
+                    return self._finalize_consume(param, value, found, NoSuchOption(f'invalid argument: {value}'))
+                # log.debug(f'{value=} may be used with {param=} as a value')
+
+            try:
+                found += param.take_action(value)
+            except UsageError as e:
+                # log.debug(f'{value=} was rejected by {param=}', exc_info=True)
+                return self._finalize_consume(param, value, found, e)
+
+        # log.debug(f'Ran out of values in deque while processing {param=}')
+        if found >= 2 and self.config.allow_backtrack:
+            found = self._maybe_backtrack(param, found)
+        return self._finalize_consume(param, None, found)
+
+    def _finalize_consume(self, param: Parameter, value: OptStr, found: int, exc: Optional[Exception] = None) -> int:
+        nargs = param.nargs
+        if nargs.satisfied(found):
             # Even if an exception was passed to this method, if the found number of values is acceptable, then it
             # doesn't need to be raised.  The value that (would have) caused the exception is added back to the deque.
             if value is not None:
@@ -339,23 +341,32 @@ class CommandParser:
         elif self._last and isinstance(param, BasePositional) and hasattr(param, '_reset'):
             self._maybe_backtrack_last(param, found)
 
-        n = param.nargs.min
-        s = '' if n == 1 else 's'
+        s = '' if (n := nargs.min) == 1 else 's'
         raise MissingArgument(param, f'expected {n} value{s}, but only found {found}')
 
 
-def _to_pop(positionals: List[BasePositional], can_pop: List[int], available: int, req_mod: int = 0) -> Optional[int]:
+def _to_pop(positionals: Iterable[BasePositional], can_pop: List[int], available: int, req_mod: int = 0) -> int:
     if not can_pop:
-        return None
+        return 0
 
-    required = nargs_min_sum(p.nargs for p in positionals)
+    required, acceptable = nargs_min_and_max_sums(p.nargs for p in positionals)
     if available < required:
-        return None
+        return 0
 
     required -= req_mod
-    acceptable = nargs_max_sum(p.nargs for p in positionals)
     for n in can_pop:
         if required <= n <= acceptable:
             return n
 
+    return 0
+
+
+def get_opt_prefix(text: str) -> OptStr:
+    if not text or text[0] != '-':
+        return None
+    n = len(text)
+    if n > 1 and text[1] != '-':
+        return '-'
+    elif n > 2 and text[2] != '-':
+        return '--'
     return None
